PathTreeMulti

Struct PathTreeMulti 

pub struct PathTreeMulti<T> {
    pub directory: DirectoryMulti<T>,
}
PathTree Multi

PathTreeMulti can store multiple files <T> on the nested DirectoryMulti

The path is also used to specify the name of the file, so the target directory is the second one from the end in cases where you work with files

Fields

directory: DirectoryMulti<T>